@@ -94,7 +94,8 @@ def try_upsert(collection: StandardCollection, record_batch: RecordBatch, force=
                 ingested_documents.labels(region_label, tenant_label, fabric_label, workflow_label).inc()
                 ingested_bytes.labels(region_label, tenant_label, fabric_label, workflow_label).inc(len(json.dumps(r)))
                 # Update ingest_lag metric
-                ingest_lag.labels(region_label, tenant_label, fabric_label, workflow_label).set((datetime.now() - to_insert[i].time_extracted).total_seconds())
+                diff = datetime.now() - datetime.fromisoformat(to_insert[i]["time_extracted"])
+                ingest_lag.labels(region_label, tenant_label, fabric_label, workflow_label).set(diff.total_seconds())
 
         if len(to_update) > 0:
             for i, r in enumerate(collection.update_many(to_update)):
@@ -104,7 +105,8 @@ def try_upsert(collection: StandardCollection, record_batch: RecordBatch, force=
                     print(f'Failed to insert/update record: {to_update[i]}. {r}')
                 else:
                     # Update ingest_lag metric
-                    ingest_lag.labels(region_label, tenant_label, fabric_label, workflow_label).set((datetime.now() - to_update[i].time_extracted).total_seconds())
+                    diff = datetime.now() - datetime.fromisoformat(to_update[i]["time_extracted"])
+                    ingest_lag.labels(region_label, tenant_label, fabric_label, workflow_label).set(diff.total_seconds())
         record_batch.last_executed_time = datetime.now()
 
 
